@@ -464,6 +464,34 @@ _babl_fish_prepare_bpp (Babl *babl)
      }
 }
 
+void
+_babl_fish_missing_fast_path_warning (const Babl *source,
+                                      const Babl *destination)
+{
+#ifndef BABL_UNSTABLE
+  if (debug_conversions)
+#endif
+  {
+    static int warnings = 0;
+
+    if (_babl_legal_error() <= 0.0000000001)
+      return;
+
+    if (warnings++ == 0)
+      fprintf (stderr,
+"Missing fast-path babl conversion detected, Implementing missing babl fast paths\n"
+"accelerates GEGL, GIMP and other software using babl, warnings are printed on\n"
+"first occurance of formats used where a conversion has to be synthesized\n"
+"programmatically by babl based on format description\n"
+"\n");
+
+    fprintf (stderr, "*WARNING* missing babl fast path(s): \"%s\" to \"%s\"\n",
+       babl_get_name (source),
+       babl_get_name (destination));
+
+  }
+}
+
 
 static Babl *
 babl_fish_path2 (const Babl *source,
@@ -571,11 +599,13 @@ babl_fish_path2 (const Babl *source,
     {
       get_conversion_path (&pc, (Babl *) source, 0, max_path_length () + 1, tolerance);
 
+#if 0
       if (babl->fish_path.conversion_list->count)
       {
         fprintf (stderr, "babl is using a rather long chain, room exists for optimization here\n");
         babl_list_each (babl->fish_path.conversion_list, show_item, NULL);
       }
+#endif
     }
 
     /* third attempt,. at path length + 2 */
@@ -583,11 +613,13 @@ babl_fish_path2 (const Babl *source,
         max_path_length () + 2 <= BABL_HARD_MAX_PATH_LENGTH)
     {
       get_conversion_path (&pc, (Babl *) source, 0, max_path_length () + 2, tolerance);
+#if 0
       if (babl->fish_path.conversion_list->count)
       {
         fprintf (stderr, "babl is using very long chain, should be optimized\n");
         babl_list_each (babl->fish_path.conversion_list, show_item, NULL);
       }
+#endif
     }
 
     babl_in_fish_path--;
@@ -599,28 +631,11 @@ babl_fish_path2 (const Babl *source,
       babl_free (babl);
       babl_mutex_unlock (babl_format_mutex);
 
-#ifndef BABL_UNSTABLE
-      if (debug_conversions)
-#endif
-      {
-        static int warnings = 0;
+      /* it is legitimate for reference paths to be faster than long chains
+         of paths, thus it is time to retire this warning. XXX: remove it fully 
 
-        if (_babl_legal_error() <= 0.0000000001)
-            return NULL;
+          _babl_fish_missing_fast_path_warning (source, destination); */
 
-        if (warnings++ == 0)
-          fprintf (stderr,
-"Missing fast-path babl conversion detected, Implementing missing babl fast paths\n"
-"accelerates GEGL, GIMP and other software using babl, warnings are printed on\n"
-"first occurance of formats used where a conversion has to be synthesized\n"
-"programmatically by babl based on format description\n"
-"\n");
-
-        fprintf (stderr, "*WARNING* missing babl fast path(s): \"%s\" to \"%s\"\n",
-           babl_get_name (source),
-           babl_get_name (destination));
-
-      }
       return NULL;
     }
 
