@@ -13,9 +13,10 @@
  *
  * You should have received a copy of the GNU Lesser General
  * Public License along with this library; if not, see
- * <http://www.gnu.org/licenses/>.
+ * <https://www.gnu.org/licenses/>.
  */
 
+#include "config.h"
 #include "babl-internal.h"
 
 static int OK;
@@ -36,22 +37,20 @@ type_sanity (Babl *babl,
 {
   /* ensure that every type has reference conversions to
    * and from double */
-  void **ptr;
-  int    ok;
+  int      ok, i;
+  BablList *list;
 
   ok = 0;
-  if (babl->type.from)
+  list = babl->type.from_list;
+  if (list)
     {
-      ptr = (void **) babl->type.from;
-
-      while (ptr && NULL != *ptr)
+      for (i = 0; i < babl_list_size (list); i++)
         {
-          if (babl_conversion_destination ((Babl *) (*ptr)) == babl_type_id (BABL_DOUBLE))
+          if (babl_conversion_destination ((Babl *) list->items[i]) == babl_type_from_id (BABL_DOUBLE))
             {
               ok = 1;
               break;
             }
-          ptr++;
         }
     }
   if (!ok)
@@ -71,22 +70,20 @@ model_sanity (Babl *babl,
 {
   /* ensure that every type has reference conversions to
    * and from rgba */
-  void **ptr;
-  int    ok;
+  int      ok, i;
+  BablList *list;
 
   ok = 0;
-  if (babl->model.from)
+  list = babl->model.from_list;
+  if (list)
     {
-      ptr = (void **) babl->model.from;
-
-      while (ptr && NULL != *ptr)
+      for (i = 0; i < babl_list_size (list); i++)
         {
-          if (babl_conversion_destination ((Babl *) (*ptr)) == babl_model_id (BABL_RGBA))
+          if (babl_conversion_destination ((Babl *) list->items[i]) == babl_model_from_id (BABL_RGBA))
             {
               ok = 1;
               break;
             }
-          ptr++;
         }
     }
   if (!ok)
@@ -118,18 +115,18 @@ int
 babl_sanity (void)
 {
   OK=1;
-  
-  babl_type_each         (id_sanity, NULL);
-  babl_component_each    (id_sanity, NULL);
-  babl_model_each        (id_sanity, NULL);
-  babl_format_each       (id_sanity, NULL);
 
-  babl_type_each         (type_sanity, NULL);
-  babl_sampling_each     (foo, NULL);
-  babl_component_each    (foo, NULL);
-  babl_model_each        (model_sanity, NULL);
-  babl_format_each       (foo, NULL);
-  babl_conversion_each   (foo, NULL);
+  babl_type_class_for_each         (id_sanity, NULL);
+  babl_component_class_for_each    (id_sanity, NULL);
+  babl_model_class_for_each        (id_sanity, NULL);
+  babl_format_class_for_each       (id_sanity, NULL);
+
+  babl_type_class_for_each         (type_sanity, NULL);
+  babl_sampling_class_for_each     (foo, NULL);
+  babl_component_class_for_each    (foo, NULL);
+  babl_model_class_for_each        (model_sanity, NULL);
+  babl_format_class_for_each       (foo, NULL);
+  babl_conversion_class_for_each   (foo, NULL);
 
   return OK;
 }
